==> client-java-api-3.0.0-sources.jar: io/kubernetes/client/models/V1DownwardAPIVolumeFileFluent.java <==
package io.kubernetes.client.models;

import com.google.gson.annotations.SerializedName;
import io.kubernetes.client.fluent.Fluent;
import io.kubernetes.client.fluent.Nested;
import java.lang.String;
import java.lang.Integer;
import java.lang.Deprecated;
import java.lang.Boolean;

public interface V1DownwardAPIVolumeFileFluent<A extends V1DownwardAPIVolumeFileFluent<A>> extends Fluent<A>{


    
/**
 * This method has been deprecated, please use method buildFieldRef instead.
 * @return The buildable object.
 */
@Deprecated public V1ObjectFieldSelector getFieldRef();
    public V1ObjectFieldSelector buildFieldRef();
    public A withFieldRef(V1ObjectFieldSelector fieldRef);
    public Boolean hasFieldRef();
    public V1DownwardAPIVolumeFileFluent.FieldRefNested<A> withNewFieldRef();
    public V1DownwardAPIVolumeFileFluent.FieldRefNested<A> withNewFieldRefLike(V1ObjectFieldSelector item);
    public V1DownwardAPIVolumeFileFluent.FieldRefNested<A> editFieldRef();
    public V1DownwardAPIVolumeFileFluent.FieldRefNested<A> editOrNewFieldRef();
    public V1DownwardAPIVolumeFileFluent.FieldRefNested<A> editOrNewFieldRefLike(V1ObjectFieldSelector item);
    public Integer getMode();
    public A withMode(Integer mode);
    public Boolean hasMode();
    public A withNewMode(int arg1);
    public A withNewMode(String arg1);
    public String getPath();
    public A withPath(String path);
    public Boolean hasPath();
    
/**
 * This method has been deprecated, please use method buildResourceFieldRef instead.
 * @return The buildable object.
 */
@Deprecated public V1ResourceFieldSelector getResourceFieldRef();
    public V1ResourceFieldSelector buildResourceFieldRef();
    public A withResourceFieldRef(V1ResourceFieldSelector resourceFieldRef);
    public Boolean hasResourceFieldRef();
    public V1DownwardAPIVolumeFileFluent.ResourceFieldRefNested<A> withNewResourceFieldRef();
    public V1DownwardAPIVolumeFileFluent.ResourceFieldRefNested<A> withNewResourceFieldRefLike(V1ResourceFieldSelector item);
    public V1DownwardAPIVolumeFileFluent.ResourceFieldRefNested<A> editResourceFieldRef();
    public V1DownwardAPIVolumeFileFluent.ResourceFieldRefNested<A> editOrNewResourceFieldRef();
    public V1DownwardAPIVolumeFileFluent.ResourceFieldRefNested<A> editOrNewResourceFieldRefLike(V1ResourceFieldSelector item);

    public interface FieldRefNested<N> extends io.kubernetes.client.fluent.Nested<N>,V1ObjectFieldSelectorFluent<V1DownwardAPIVolumeFileFluent.FieldRefNested<N>>{

        
    public N and();    public N endFieldRef();
}
    public interface ResourceFieldRefNested<N> extends io.kubernetes.client.fluent.Nested<N>,V1ResourceFieldSelectorFluent<V1DownwardAPIVolumeFileFluent.ResourceFieldRefNested<N>>{

        
    public N and();    public N endResourceFieldRef();
}


}

==> client-java-api-5.0.0-sources.jar: io/kubernetes/client/models/V1DownwardAPIVolumeFileFluent.java <==
package io.kubernetes.client.models;

import java.lang.StringBuilder;
import com.google.gson.annotations.SerializedName;
import io.kubernetes.client.fluent.Fluent;
import io.kubernetes.client.fluent.Nested;
import java.lang.String;
import java.lang.Integer;
import java.lang.StringBuffer;
import java.lang.Deprecated;
import java.lang.Boolean;

public interface V1DownwardAPIVolumeFileFluent<A extends V1DownwardAPIVolumeFileFluent<A>> extends Fluent<A>{


    
/**
 * This method has been deprecated, please use method buildFieldRef instead.
 * @return The buildable object.
 */
@Deprecated public V1ObjectFieldSelector getFieldRef();
    public V1ObjectFieldSelector buildFieldRef();
    public A withFieldRef(V1ObjectFieldSelector fieldRef);
    public Boolean hasFieldRef();
    public V1DownwardAPIVolumeFileFluent.FieldRefNested<A> withNewFieldRef();
    public V1DownwardAPIVolumeFileFluent.FieldRefNested<A> withNewFieldRefLike(V1ObjectFieldSelector item);
    public V1DownwardAPIVolumeFileFluent.FieldRefNested<A> editFieldRef();
    public V1DownwardAPIVolumeFileFluent.FieldRefNested<A> editOrNewFieldRef();
    public V1DownwardAPIVolumeFileFluent.FieldRefNested<A> editOrNewFieldRefLike(V1ObjectFieldSelector item);
    public Integer getMode();
    public A withMode(Integer mode);
    public Boolean hasMode();
    public String getPath();
    public A withPath(String path);
    public Boolean hasPath();
    public A withNewPath(String arg1);
    public A withNewPath(StringBuilder arg1);
    public A withNewPath(StringBuffer arg1);
    
/**
 * This method has been deprecated, please use method buildResourceFieldRef instead.
 * @return The buildable object.
 */
@Deprecated public V1ResourceFieldSelector getResourceFieldRef();
    public V1ResourceFieldSelector buildResourceFieldRef();
    public A withResourceFieldRef(V1ResourceFieldSelector resourceFieldRef);
    public Boolean hasResourceFieldRef();
    public V1DownwardAPIVolumeFileFluent.ResourceFieldRefNested<A> withNewResourceFieldRef();
    public V1DownwardAPIVolumeFileFluent.ResourceFieldRefNested<A> withNewResourceFieldRefLike(V1ResourceFieldSelector item);
    public V1DownwardAPIVolumeFileFluent.ResourceFieldRefNested<A> editResourceFieldRef();
    public V1DownwardAPIVolumeFileFluent.ResourceFieldRefNested<A> editOrNewResourceFieldRef();
    public V1DownwardAPIVolumeFileFluent.ResourceFieldRefNested<A> editOrNewResourceFieldRefLike(V1ResourceFieldSelector item);

    public interface FieldRefNested<N> extends io.kubernetes.client.fluent.Nested<N>,V1ObjectFieldSelectorFluent<V1DownwardAPIVolumeFileFluent.FieldRefNested<N>>{

        
    public N and();    public N endFieldRef();
}
    public interface ResourceFieldRefNested<N> extends io.kubernetes.client.fluent.Nested<N>,V1ResourceFieldSelectorFluent<V1DownwardAPIVolumeFileFluent.ResourceFieldRefNested<N>>{

        
    public N and();    public N endResourceFieldRef();
}


}
